
#import "BaseViewController.h"

@interface BaseViewController () {
    UITapGestureRecognizer* tapGesture;
}

@end

@implementation BaseViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(keyboardWillShowWithNotification:)
                                                 name:UIKeyboardWillShowNotification
                                               object:nil];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(keyboardWillHideWithNotification:) name:UIKeyboardWillHideNotification
                                               object:nil];
}

- (void) forceEndInput {
    [self.view endEditing:YES];
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    
    [SharedLabelPrinterSDK sharedInstance].delegate = self;
}

#pragma mark - Keyboard control
- (void) keyboardWillShowWithNotification:(NSNotification *)notification {
    CGFloat height = [[[notification userInfo] objectForKey:UIKeyboardFrameEndUserInfoKey] CGRectValue].size.height;
    
    [_scr setContentInset:UIEdgeInsetsMake(0, 0, height, 0)];
    
    if (tapGesture != nil && [self.view.gestureRecognizers containsObject:tapGesture]) {
        [self.view removeGestureRecognizer:tapGesture];
    }
    
    tapGesture = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(forceEndInput)];
    [self.view addGestureRecognizer:tapGesture];
}

- (void) keyboardWillHideWithNotification:(NSNotification *)notification {
    [_scr setContentInset:UIEdgeInsetsMake(0, 0, 0, 0)];
    
    if (tapGesture != nil && [self.view.gestureRecognizers containsObject:tapGesture]) {
        [self.view removeGestureRecognizer:tapGesture];
    }
}


#pragma mark - Alert
- (void) presentTextAlertWithTitle:(NSString *)title msg:(NSString *)msg {
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:title
                                                                   message:msg
                                                            preferredStyle:UIAlertControllerStyleAlert];
    [alert addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:nil]];
    [self presentViewController:alert animated:YES completion:nil];
}


# pragma mark - UITextField Delegate
- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    [textField resignFirstResponder];
    return YES;
}

# pragma mark - LabelPrinterSDK Delegate
- (void)willConnect:(LabelPrinterSDK *)controller printer:(LabelPrinterObject *)printer {}
- (void)didConnect:(LabelPrinterSDK *)controller printer:(LabelPrinterObject *)printer {}
- (void)didNotConnect:(LabelPrinterSDK *)controller printer:(LabelPrinterObject *)printer withError:(NSError *)error {}
- (void)didBeBrokenConnection:(LabelPrinterSDK *)controller printer:(LabelPrinterObject *)printer withError:(NSError *)error{
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:nil
                                                                        message:@"Printer Disconnect"
                                                                 preferredStyle:UIAlertControllerStyleAlert];
    
    [alert addAction:[UIAlertAction actionWithTitle:@"OK"
                                              style:UIAlertActionStyleDefault
                                            handler:^(UIAlertAction * _Nonnull action) {
        [self.navigationController popToRootViewControllerAnimated:YES];
    }]];
    
    [self presentViewController:alert animated:YES completion:nil];
}
- (void)willLookupPrinter:(LabelPrinterSDK *)controller{}
- (void)didFindPrinter:(LabelPrinterSDK *)controller printer:(LabelPrinterObject *)printer{}
- (void)didLookupPrinters:(LabelPrinterSDK *)controller printerList:(NSArray *)printerList{}
- (void)canNotFoundPrinter{}

- (void)didDisconnect:(LabelPrinterSDK *)controller printer:(LabelPrinterObject *)printer {}

@end
