
#import "Draw1DBarcodeViewController.h"

@interface Draw1DBarcodeViewController () {
    LabelPrinterSDK *printer;
    
    NSArray<NSNumber*>* barcodeList;
    NSArray<NSString*>* barcodeDescList;
    NSArray<NSNumber*>* barcodeHriList;
    NSArray<NSString*>* barcodeHriDescList;
    
    SDK_BARCODE_TYPE barcode;
    SDK_BARCODE_HRI hri;
}

@end

@implementation Draw1DBarcodeViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    printer = SharedLabelPrinterSDK.sharedInstance;
    
    barcodeList = @[
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_CODE39],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_CODE128],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_I2Of5],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_CODABAR],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_CODE93],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_UPC_A],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_UPC_E],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_EAN13],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_EAN8],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_EAN128],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_CODE11],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_PLANET],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_INDUSTRIAL_2Of5],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_STANDARD_2Of5],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_LOGMARS],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_UPC_EAN_EXTENSIONS],
        [NSNumber numberWithInt:SDK_BARCODE_TYPE_POSTNET]
    ];
    
    barcodeDescList = @[
        @"CODE39",
        @"CODE128",
        @"I2Of5",
        @"CODABAR",
        @"CODE93",
        @"UPC_A",
        @"UPC_E",
        @"EAN13",
        @"EAN8",
        @"EAN128",
        @"CODE11",
        @"PLANET",
        @"INDUSTRIAL_2Of5",
        @"STANDARD_2Of5",
        @"LOGMARS",
        @"UPC_EAN_EXTENSIONS",
        @"POSTNET"
    ];
    
    barcodeHriList = @[
        [NSNumber numberWithInt:SDK_BARCODE_HRI_NONE],
        [NSNumber numberWithInt:SDK_BARCODE_HRI_BELOW_FONTSIZE1],
        [NSNumber numberWithInt:SDK_BARCODE_HRI_ABOVE_FONTSIZE1],
        [NSNumber numberWithInt:SDK_BARCODE_HRI_BELOW_FONTSIZE2],
        [NSNumber numberWithInt:SDK_BARCODE_HRI_ABOVE_FONTSIZE2],
        [NSNumber numberWithInt:SDK_BARCODE_HRI_BELOW_FONTSIZE3],
        [NSNumber numberWithInt:SDK_BARCODE_HRI_ABOVE_FONTSIZE3],
        [NSNumber numberWithInt:SDK_BARCODE_HRI_BELOW_FONTSIZE4],
        [NSNumber numberWithInt:SDK_BARCODE_HRI_ABOVE_FONTSIZE4]
    ];
    
    barcodeHriDescList = @[
        @"NONE",
        @"BELOW_FONTSIZE1",
        @"ABOVE_FONTSIZE1",
        @"BELOW_FONTSIZE2",
        @"ABOVE_FONTSIZE2",
        @"BELOW_FONTSIZE3",
        @"ABOVE_FONTSIZE3",
        @"BELOW_FONTSIZE4",
        @"ABOVE_FONTSIZE4"
    ];
    
    barcode = barcodeList.firstObject.intValue;
    hri = barcodeHriList.firstObject.intValue;
    
    [_btnBarcode setTitle:barcodeDescList.firstObject forState:UIControlStateNormal];
    [_btnBarcodeHRI setTitle:barcodeHriDescList.firstObject forState:UIControlStateNormal];
}

- (IBAction)selectBarcode:(UIButton*)sender {
    UIAlertController *controller = [UIAlertController alertControllerWithTitle:nil
                                                                        message:nil
                                                                 preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger idx = 0; idx < barcodeDescList.count; idx++) {
        [controller addAction:[UIAlertAction actionWithTitle:barcodeDescList[idx]
                                                       style:UIAlertActionStyleDefault
                                                     handler:^(UIAlertAction * _Nonnull action) {
            [self->_btnBarcode setTitle:self->barcodeDescList[idx]
                                 forState:UIControlStateNormal];
            self->barcode = self->barcodeList[idx].intValue;
        }]];
    }
    
    [controller addAction:[UIAlertAction actionWithTitle:@"Cancel"
                                                   style:UIAlertActionStyleCancel
                                                 handler:nil]];
    [self presentViewController:controller animated:YES completion:nil];
}

- (IBAction)selectBarcodeHri:(UIButton*)sender {
    UIAlertController *controller = [UIAlertController alertControllerWithTitle:nil
                                                                        message:nil
                                                                 preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger idx = 0; idx < barcodeHriDescList.count; idx++) {
        [controller addAction:[UIAlertAction actionWithTitle:barcodeHriDescList[idx]
                                                       style:UIAlertActionStyleDefault
                                                     handler:^(UIAlertAction * _Nonnull action) {
            [self->_btnBarcodeHRI setTitle:self->barcodeHriDescList[idx]
                                 forState:UIControlStateNormal];
            self->hri = self->barcodeHriList[idx].intValue;
        }]];
    }
    
    [controller addAction:[UIAlertAction actionWithTitle:@"Cancel"
                                                   style:UIAlertActionStyleCancel
                                                 handler:nil]];
    [self presentViewController:controller animated:YES completion:nil];
}

- (IBAction)print:(UIButton*)sender {
    NSString *text = _tfText.text;
    NSInteger xPos = _tfXpos.text.integerValue;
    NSInteger yPos = _tfYpos.text.integerValue;
    
    NSInteger narrow = _tfNarrow.text.integerValue;
    NSInteger wide = _tfWide.text.integerValue;
    NSInteger height = _tfHeight.text.integerValue;
    
    
    SDK_ROTATION_DEGREES rotation = SDK_ROTATION_DEGREES_0;
    switch (_segRotation.selectedSegmentIndex) {
        case 0: rotation = SDK_ROTATION_DEGREES_0; break;
        case 1: rotation = SDK_ROTATION_DEGREES_90; break;
        case 2: rotation = SDK_ROTATION_DEGREES_180; break;
        case 3: rotation = SDK_ROTATION_DEGREES_270; break;
        default:
            rotation = SDK_ROTATION_DEGREES_0;
            break;
    }
    
    SDK_RESULT_CODES result = [printer drawBarcode1D:text
                                              xPosition:xPos
                                              yPosition:yPos
                                            barcodeType:barcode
                                            widthNarrow:narrow
                                              widthWide:wide
                                                 height:height
                                                    hri:hri
                                         quietZoneWidth:0
                                               rotation:rotation];

    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Draw Fail"];
        return;
    }
    
    result = [printer doPrint:1];
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Print Fail"];
        return;
    }
}

@end
