
#import "DrawBlockViewController.h"

@interface DrawBlockViewController () {
    LabelPrinterSDK *printer;
    NSArray<NSNumber*>* optionList;
    NSArray<NSString*>* optionDescList;
    SDK_DRAW_BLOCK_OPTION option;
}

@end

@implementation DrawBlockViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    printer = SharedLabelPrinterSDK.sharedInstance;
    optionList = @[
        [NSNumber numberWithChar:SDK_DRAW_BLOCK_OPTION_LINE_OVERWRITING],
        [NSNumber numberWithChar:SDK_DRAW_BLOCK_OPTION_LINE_EXCLUSIVE_OR],
        [NSNumber numberWithChar:SDK_DRAW_BLOCK_OPTION_LINE_DELETE],
        [NSNumber numberWithChar:SDK_DRAW_BLOCK_OPTION_SLOPE],
        [NSNumber numberWithChar:SDK_DRAW_BLOCK_OPTION_BOX],
    ];
    
    optionDescList = @[
        @"Line over writing",
        @"Line exclusive or",
        @"Line delete",
        @"Slope",
        @"BOX"
    ];
    
    option = optionList.firstObject.charValue;
    [_btnType setTitle:optionDescList.firstObject forState:UIControlStateNormal];
}

- (IBAction)selectType:(UIButton *)sender {
    UIAlertController *controller = [UIAlertController alertControllerWithTitle:nil
                                                                        message:nil
                                                                 preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger idx = 0; idx < optionDescList.count; idx++) {
        [controller addAction:[UIAlertAction actionWithTitle:optionDescList[idx]
                                                       style:UIAlertActionStyleDefault
                                                     handler:^(UIAlertAction * _Nonnull action) {
            [self->_btnType setTitle:self->optionDescList[idx]
                                 forState:UIControlStateNormal];
            self->option = self->optionList[idx].charValue;
        }]];
    }
    
    [controller addAction:[UIAlertAction actionWithTitle:@"Cancel"
                                                   style:UIAlertActionStyleCancel
                                                 handler:nil]];
    [self presentViewController:controller animated:YES completion:nil];
}

- (IBAction)print:(UIButton*)sender {
    NSInteger startXpos = _tfStartXpos.text.integerValue;
    NSInteger startYpos = _tfStartYpos.text.integerValue;
    NSInteger endXpos = _tfEndXpos.text.integerValue;
    NSInteger endYpos = _tfEndYpos.text.integerValue;
    
    NSInteger thickness = _tfThickness.text.integerValue;
    
    SDK_RESULT_CODES result = [printer drawBlock:startXpos
                                          startPosY:startYpos
                                            endPosX:endXpos
                                            endPosY:endYpos
                                             option:option
                                          thickness:thickness];
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Draw Fail"];
        return;
    }
    
    result = [printer doPrint:1];
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Print Fail"];
        return;
    }
}

@end
