
#import "DrawDeviceFontViewController.h"

@interface DrawDeviceFontViewController () {
    LabelPrinterSDK *printer;
    
    NSArray<NSNumber*>* fontList;
    NSArray<NSString*>* fontDescList;

    SDK_DEVICE_FONT font;
}

@end

@implementation DrawDeviceFontViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    printer = SharedLabelPrinterSDK.sharedInstance;
    fontList = @[
        [NSNumber numberWithChar:SDK_DEVICE_FONT_6PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_8PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_10PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_12PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_15PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_20PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_30PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_14PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_18PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_24PT],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_KOREAN1],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_KOREAN2],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_KOREAN3],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_KOREAN4],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_KOREAN5],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_KOREAN6],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_GB2312],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_BIG5],
        [NSNumber numberWithChar:SDK_DEVICE_FONT_SHIFT_JIS],
    ];
    
    fontDescList = @[
        @"DEVICE_FONT_6PT",
        @"DEVICE_FONT_8PT",
        @"DEVICE_FONT_10PT",
        @"DEVICE_FONT_12PT",
        @"DEVICE_FONT_15PT",
        @"DEVICE_FONT_20PT",
        @"DEVICE_FONT_30PT",
        @"DEVICE_FONT_14PT",
        @"DEVICE_FONT_18PT",
        @"DEVICE_FONT_24PT",
        @"DEVICE_FONT_KOREAN1",
        @"DEVICE_FONT_KOREAN2",
        @"DEVICE_FONT_KOREAN3",
        @"DEVICE_FONT_KOREAN4",
        @"DEVICE_FONT_KOREAN5",
        @"DEVICE_FONT_KOREAN6",
        @"DEVICE_FONT_GB2312",
        @"DEVICE_FONT_BIG5",
        @"DEVICE_FONT_SHIFT_JIS"
    ];
    
    font = fontList.firstObject.charValue;
    [_btnFont setTitle:fontDescList.firstObject
              forState:UIControlStateNormal];
}

- (IBAction)selectFont:(UIButton *)sender {
    UIAlertController *controller = [UIAlertController alertControllerWithTitle:nil
                                                                        message:nil
                                                                 preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger idx = 0; idx < fontDescList.count; idx++) {
        [controller addAction:[UIAlertAction actionWithTitle:fontDescList[idx]
                                                       style:UIAlertActionStyleDefault
                                                     handler:^(UIAlertAction * _Nonnull action) {
            [self->_btnFont setTitle:self->fontDescList[idx]
                                 forState:UIControlStateNormal];
            self->font = self->fontList[idx].charValue;
        }]];
    }
    
    [controller addAction:[UIAlertAction actionWithTitle:@"Cancel"
                                                   style:UIAlertActionStyleCancel
                                                 handler:nil]];
    [self presentViewController:controller animated:YES completion:nil];
}

- (IBAction)print:(UIButton*)sender {
    NSString *text = _tfText.text;
    NSInteger xPos = _tfXpos.text.integerValue;
    NSInteger yPos = _tfYpos.text.integerValue;
    NSInteger width = _tfHorizontalMulti.text.integerValue;
    NSInteger height = _tfVerticalMulti.text.integerValue;
    NSInteger rightSpacing = _tfRightSpace.text.integerValue;
    
    SDK_ROTATION_DEGREES rotation = SDK_ROTATION_DEGREES_0;
    switch (_segRotation.selectedSegmentIndex) {
        case 0: rotation = SDK_ROTATION_DEGREES_0; break;
        case 1: rotation = SDK_ROTATION_DEGREES_90; break;
        case 2: rotation = SDK_ROTATION_DEGREES_180; break;
        case 3: rotation = SDK_ROTATION_DEGREES_270; break;
        default:
            rotation = SDK_ROTATION_DEGREES_0;
            break;
    }
    
    SDK_ALIGNMENT alignment = SDK_ALIGNMENT_LEFT;
    switch (_segAlignment.selectedSegmentIndex) {
        case 0: alignment = SDK_ALIGNMENT_LEFT; break;
        case 1: alignment = SDK_ALIGNMENT_RIGHT; break;
        case 2: alignment = SDK_ALIGNMENT_STRING_FROM_RIGHT_2_LEFT; break;
        default:
            alignment = SDK_ALIGNMENT_LEFT;
            break;
    }
    
    BOOL reverse = _segReverse.selectedSegmentIndex == 1;
    BOOL bold = _segBold.selectedSegmentIndex == 1;
    
    SDK_RESULT_CODES result = [printer drawTextDeviceFont:text
                                                   xPosition:xPos
                                                   yPosition:yPos
                                               fontSelection:font
                                                   fontWidth:width
                                                  fontHeight:height
                                   rightSideCharacterSpacing:rightSpacing
                                                fontRotation:rotation
                                                     reverse:reverse
                                                        bold:bold
                                               textAlignment:alignment];
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Draw Fail"];
        return;
    }
    
    result = [printer doPrint:1];
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Print Fail"];
        return;
    }
}

@end
