
#import "DrawPDF417ViewController.h"

@interface DrawPDF417ViewController (){
    LabelPrinterSDK* printer;
    NSArray<NSString*>* errorDescList;
    NSArray<NSNumber*>* errorCorrectionLevelList;
    SDK_ERROR_CORRECTION_LEVEL err;
}

@end

@implementation DrawPDF417ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    printer = SharedLabelPrinterSDK.sharedInstance;
    
    errorDescList = @[
        @"LEVEL 0",
        @"LEVEL 1",
        @"LEVEL 2",
        @"LEVEL 3",
        @"LEVEL 4",
        @"LEVEL 5",
        @"LEVEL 6",
        @"LEVEL 7",
        @"LEVEL 8"
    ];
    
    errorCorrectionLevelList = @[
        [NSNumber numberWithInt:SDK_ERROR_CORRECTION_LEVEL0],
        [NSNumber numberWithInt:SDK_ERROR_CORRECTION_LEVEL1],
        [NSNumber numberWithInt:SDK_ERROR_CORRECTION_LEVEL2],
        [NSNumber numberWithInt:SDK_ERROR_CORRECTION_LEVEL3],
        [NSNumber numberWithInt:SDK_ERROR_CORRECTION_LEVEL4],
        [NSNumber numberWithInt:SDK_ERROR_CORRECTION_LEVEL5],
        [NSNumber numberWithInt:SDK_ERROR_CORRECTION_LEVEL6],
        [NSNumber numberWithInt:SDK_ERROR_CORRECTION_LEVEL7],
        [NSNumber numberWithInt:SDK_ERROR_CORRECTION_LEVEL8]
    ];
    
    err = errorCorrectionLevelList.firstObject.intValue;
    [_btnErrorCorrectionLevel setTitle:errorDescList.firstObject forState:UIControlStateNormal];
}

-(IBAction)selectErrorLevel:(UIButton*)sender {
    UIAlertController *controller = [UIAlertController alertControllerWithTitle:nil
                                                                        message:nil
                                                                 preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger idx = 0; idx < errorDescList.count; idx++) {
        [controller addAction:[UIAlertAction actionWithTitle:errorDescList[idx]
                                                       style:UIAlertActionStyleDefault
                                                     handler:^(UIAlertAction * _Nonnull action) {
            [self->_btnErrorCorrectionLevel setTitle:self->errorDescList[idx]
                                 forState:UIControlStateNormal];
            self->err = [self->errorCorrectionLevelList[idx] intValue];
        }]];
    }
    
    [controller addAction:[UIAlertAction actionWithTitle:@"Cancel"
                                                   style:UIAlertActionStyleCancel
                                                 handler:nil]];
    [self presentViewController:controller animated:YES completion:nil];
}

-(IBAction)print:(UIButton*)sender {
    NSString *text = _tfText.text;
    NSInteger xPos = _tfXpos.text.integerValue;
    NSInteger yPos = _tfYpos.text.integerValue;
    NSInteger rowCount = _tfRowCount.text.integerValue;
    NSInteger columnCount = _tfColumnCount.text.integerValue;
    NSInteger moduleWidth = _tfWidth.text.integerValue;
    NSInteger barHeight = _tfHeight.text.integerValue;
    
    SDK_DATA_COMPRESSION_METHOD dataCompressionMethod = SDK_DATA_COMPRESSION_METHOD_TEXT;
    switch (_segDataCompressionMethod.selectedSegmentIndex) {
        case 0: dataCompressionMethod = SDK_DATA_COMPRESSION_METHOD_TEXT; break;
        case 1: dataCompressionMethod = SDK_DATA_COMPRESSION_METHOD_NUMERIC; break;
        case 2: dataCompressionMethod = SDK_DATA_COMPRESSION_METHOD_BINARY; break;
        default: dataCompressionMethod = SDK_DATA_COMPRESSION_METHOD_TEXT; break;
    }
    
    BOOL printBarcodeText = _segBarcodeText.selectedSegmentIndex == 1;
    SDK_BARCODE_ORIGIN_POINT originPoint = _segOriginPoint.selectedSegmentIndex == 1 ? SDK_BARCODE_ORIGIN_POINT_CENTER : SDK_BARCODE_ORIGIN_POINT_UPPER_LEFT;
    
    SDK_ROTATION_DEGREES rotation = SDK_ROTATION_DEGREES_0;
    switch (_segRotation.selectedSegmentIndex) {
        case 0: rotation = SDK_ROTATION_DEGREES_0; break;
        case 1: rotation = SDK_ROTATION_DEGREES_90; break;
        case 2: rotation = SDK_ROTATION_DEGREES_180; break;
        case 3: rotation = SDK_ROTATION_DEGREES_270; break;
        default:
            rotation = SDK_ROTATION_DEGREES_0;
            break;
    }
    
    
    SDK_RESULT_CODES result = [printer drawBarcodePDF417:text
                                                  xPosition:xPos
                                                  yPosition:yPos
                                            maximumRowCount:rowCount
                                         maximumColumnCount:columnCount
                                       errorCorrectionLevel:err
                                      dataCompressionMethod:dataCompressionMethod
                                           printBarcodeText:printBarcodeText
                                         barcodeOriginPoint:originPoint
                                                moduleWidth:moduleWidth
                                                  barHeight:barHeight
                                                   rotation:rotation];
    
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Draw Fail"];
        return;
    }
    
    result = [printer doPrint:1];
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Print Fail"];
        return;
    }
    
    
}


@end
