
#import "DrawVectorFontViewController.h"

@interface DrawVectorFontViewController () {
    LabelPrinterSDK *printer;
    NSArray<NSNumber *>* fontList;
    NSArray<NSString *>* fontDescList;
    SDK_VECTOR_FONT font;
}

@end

@implementation DrawVectorFontViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    printer = SharedLabelPrinterSDK.sharedInstance;
    fontList = @[
        [NSNumber numberWithChar:SDK_VECTOR_FONT_ASCII],
        [NSNumber numberWithChar:SDK_VECTOR_FONT_KS5601],
        [NSNumber numberWithChar:SDK_VECTOR_FONT_BIG5],
        [NSNumber numberWithChar:SDK_VECTOR_FONT_GB2312],
        [NSNumber numberWithChar:SDK_VECTOR_FONT_SHIFT_JIS],
        [NSNumber numberWithChar:SDK_VECTOR_FONT_OCR_A],
        [NSNumber numberWithChar:SDK_VECTOR_FONT_OCR_B]
    ];
    fontDescList = @[
        @"ASCII",
        @"BIG5",
        @"GB2312",
        @"SHIFT_JIS",
        @"OCR_A",
        @"OCR_B"
    ];
    
    font = fontList.firstObject.charValue;
    [_btnFont setTitle:fontDescList.firstObject forState:UIControlStateNormal];
}

- (IBAction)selectFont:(UIButton *)sender {
    UIAlertController *controller = [UIAlertController alertControllerWithTitle:nil
                                                                        message:nil
                                                                 preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger idx = 0; idx < fontDescList.count; idx++) {
        [controller addAction:[UIAlertAction actionWithTitle:fontDescList[idx]
                                                       style:UIAlertActionStyleDefault
                                                     handler:^(UIAlertAction * _Nonnull action) {
            [self->_btnFont setTitle:self->fontDescList[idx]
                                 forState:UIControlStateNormal];
            self->font = self->fontList[idx].charValue;
        }]];
    }
    
    [controller addAction:[UIAlertAction actionWithTitle:@"Cancel"
                                                   style:UIAlertActionStyleCancel
                                                 handler:nil]];
    [self presentViewController:controller animated:YES completion:nil];
}

- (IBAction)print:(UIButton*)sender {
    NSString *text = _tfText.text;
    NSInteger xPos = _tfXpos.text.integerValue;
    NSInteger yPos = _tfYpos.text.integerValue;
    NSInteger width = _tfWidth.text.integerValue;
    NSInteger height = _tfHeight.text.integerValue;
    NSInteger rightSpacing = _tfRightSpace.text.integerValue;
    
    SDK_ROTATION_DEGREES rotation = SDK_ROTATION_DEGREES_0;
    switch (_segRotation.selectedSegmentIndex) {
        case 0: rotation = SDK_ROTATION_DEGREES_0; break;
        case 1: rotation = SDK_ROTATION_DEGREES_90; break;
        case 2: rotation = SDK_ROTATION_DEGREES_180; break;
        case 3: rotation = SDK_ROTATION_DEGREES_270; break;
        default:
            rotation = SDK_ROTATION_DEGREES_0;
            break;
    }
    
    SDK_ALIGNMENT alignment = SDK_ALIGNMENT_LEFT;
    switch (_segAlignment.selectedSegmentIndex) {
        case 0: alignment = SDK_ALIGNMENT_LEFT; break;
        case 1: alignment = SDK_ALIGNMENT_RIGHT; break;
        case 2: alignment = SDK_ALIGNMENT_CENTER; break;
        default:
            alignment = SDK_ALIGNMENT_LEFT;
            break;
    }
    
    BOOL reverse = _segReverse.selectedSegmentIndex == 1;
    BOOL bold = _segBold.selectedSegmentIndex == 1;
    BOOL italic = _segItalic.selectedSegmentIndex == 1;
    BOOL r2l = _segWriteDirection.selectedSegmentIndex == 1;
    
    SDK_RESULT_CODES result = [printer drawTextVectorFont:text
                                                   xPosition:xPos
                                                   yPosition:yPos
                                               fontSelection:font
                                                   fontWidth:width
                                                  fontHeight:height
                                   rightSideCharacterSpacing:rightSpacing
                                                fontRotation:rotation
                                                     reverse:reverse
                                                        bold:bold
                                                      italic:italic
                               textWriteDirectionRightToLeft:r2l
                                               textAlignment:alignment];
    
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Draw Fail"];
        return;
    }
    
    result = [printer doPrint:1];
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Print Fail"];
        return;
    }
}

@end
