
#import "SetCharacterSetViewController.h"

@interface SetCharacterSetViewController (){
    
    NSArray<NSString *>* icsDescList;
    NSArray<NSNumber *>* icsList;
    NSArray<NSString *>* codePageDescList;
    NSArray<NSNumber *>* codePageList;

    SDK_CONFIG_ICS ics;
    SDK_CONFIG_CODEPAGE codePage;
    
    LabelPrinterSDK *printer;
}

@end

@implementation SetCharacterSetViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    icsDescList = @[
        @"U.S.A",
        @"France",
        @"Germany",
        @"U.K",
        @"Denmark I",
        @"Sweden",
        @"Italy",
        @"Spain I",
        @"Norway",
        @"Denmark II",
        @"Japan",
        @"Spain II",
        @"Latin America",
        @"Korea",
        @"Slovenia/Croatia",
        @"China"
    ];
    
    codePageDescList = @[
        @"PC437 - USA",
        @"PC850 - Latin 1",
        @"PC852 - Latin 2",
        @"PC860 - Portuguese",
        @"PC863 - Canadian French",
        @"PC865 - Nordic",
        @"WPC1252 - Latin 1",
        @"PC865 + WPC1252 - European Combined",
        @"PC857 - Turkish",
        @"PC737 - Greek",
        @"WPC1250 - Latin 2",
        @"WPC1253 - Greek",
        @"WPC1254 - Turkish",
        @"PC855 - Cyrillic",
        @"PC862 - Hebrew",
        @"PC866 - Cyrillic",
        @"WPC1251 - Cyrillic",
        @"WPC1255 - Hebrew",
        @"PC928 - Greek",
        @"PC864 - Arabic",
        @"PC775 - Baltic Dos",
        @"WPC1257 - Baltic Windows",
        @"PC858 - Latin 1 + Euro"
    ];
    
    icsList = @[
        [NSNumber numberWithInt:SDK_CONFIG_ICS_USA],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_FRANCE],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_GERMANY],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_UK],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_DENMARK_I],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_SWEDEN],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_ITALY],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_SPAIN_I],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_NORWAY],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_DENMARK_II],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_JAPAN],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_SPAIN_II],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_LATIN_AMERICA],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_KOREA],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_SLOVENIA_CROATIA],
        [NSNumber numberWithInt:SDK_CONFIG_ICS_CHINA]
    ];
    
    codePageList = @[
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP437],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP850],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP852],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP860],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP863],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP865],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP1252],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP865_WCP1252],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP857],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP737],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_WCP1250],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_WCP1253],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_WCP1254],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP855],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP862],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP866],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_WCP1251],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_WCP1255],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP928],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP864],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP775],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_WCP1257],
        [NSNumber numberWithInt:SDK_CONFIG_CODEPAGE_CP858]
    ];
    
    ics = icsList.firstObject.intValue;
    codePage = codePageList.firstObject.intValue;

    printer = SharedLabelPrinterSDK.sharedInstance;
    
    [_btnCodePage setTitle:codePageDescList.firstObject forState:UIControlStateNormal];
    [_btnICS setTitle:icsDescList.firstObject forState:UIControlStateNormal];
}

-(IBAction)setICS:(UIButton *)sender {
    UIAlertController *controller = [UIAlertController alertControllerWithTitle:nil
                                                                        message:nil
                                                                 preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger idx = 0; idx < icsDescList.count; idx++) {
        [controller addAction:[UIAlertAction actionWithTitle:icsDescList[idx]
                                                       style:UIAlertActionStyleDefault
                                                     handler:^(UIAlertAction * _Nonnull action) {
            [self->_btnICS setTitle:self->icsDescList[idx]
                                 forState:UIControlStateNormal];
            self->ics = [self->icsList[idx] intValue];
        }]];
    }
    
    [controller addAction:[UIAlertAction actionWithTitle:@"Cancel"
                                                   style:UIAlertActionStyleCancel
                                                 handler:nil]];
    [self presentViewController:controller animated:YES completion:nil];
}

-(IBAction)setCodePage:(UIButton *)sender {
    UIAlertController *controller = [UIAlertController alertControllerWithTitle:nil
                                                                        message:nil
                                                                 preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger idx = 0; idx < codePageDescList.count; idx++) {
        [controller addAction:[UIAlertAction actionWithTitle:codePageDescList[idx]
                                                       style:UIAlertActionStyleDefault
                                                     handler:^(UIAlertAction * _Nonnull action) {
            [self->_btnCodePage setTitle:self->codePageDescList[idx]
                                 forState:UIControlStateNormal];
            self->codePage = [self->codePageList[idx] intValue];
        }]];
    }
    
    [controller addAction:[UIAlertAction actionWithTitle:@"Cancel"
                                                   style:UIAlertActionStyleCancel
                                                 handler:nil]];
    [self presentViewController:controller animated:YES completion:nil];
}

- (IBAction) acceptSetting:(UIButton *)sender {
    
    SDK_RESULT_CODES result = [printer setICS:ics codepage:codePage];
    
    if (result != SDK_RESULT_SUCCESS) {
        [self presentTextAlertWithTitle:nil msg:@"Fail"];
        return;
    }
}

@end
