
#import <Foundation/Foundation.h>
#import "LabelPrinterObject.h"
#import "LabelPrinterSDK_Defines.h"
#import <UIKit/UIKit.h>

//////////////////////////////////////////////////////////////////////////////////
@class LabelPrinterSDK;
@protocol LabelPrinterSDKDelegate<NSObject>

@required
- (void)willConnect:(LabelPrinterSDK *)controller
            printer:(LabelPrinterObject *)printer;
- (void)didConnect:(LabelPrinterSDK *)controller
           printer:(LabelPrinterObject *)printer;
- (void)didNotConnect:(LabelPrinterSDK *)controller
              printer:(LabelPrinterObject *)printer
            withError:(NSError *)error;
- (void)didDisconnect:(LabelPrinterSDK *)controller
              printer:(LabelPrinterObject *)printer;
- (void)didBeBrokenConnection:(LabelPrinterSDK *)controller
                      printer:(LabelPrinterObject *)printer
                    withError:(NSError *)error;

- (void)willLookupPrinter:(LabelPrinterSDK *)controller;

- (void)didFindPrinter:(LabelPrinterSDK *)controller
               printer:(LabelPrinterObject *)printer;

- (void)didLookupPrinters:(LabelPrinterSDK *)controller
              printerList:(NSArray *)printerList;

- (void)canNotFoundPrinter;


@optional
- (void)hasDataAvailable:(LabelPrinterSDK *)controller
                    data:(NSData*)data;
@end
//////////////////////////////////////////////////////////////////////////////////



@interface LabelPrinterSDK : NSObject

@property (weak, nonatomic)                id<LabelPrinterSDKDelegate>    delegate;

/* getting SDK Informations */
+(NSString*)getSDKVersionString;
+(NSString*)getReleasedDateString;


/* search APIs */
-(NSArray*)getPairedDevices;

-(NSArray*)getSearchedDevices;
- (void)lookupPrinterWithCount:(CGFloat) lookupCount
                      interval:(CGFloat) interval;

+ (void) setEnableLog:(BOOL)enable saveFile:(BOOL)saveFile hexDump:(BOOL)hexDump;

- (SDK_RESULT_CODES) cancelToLookupPrinter;


/* connect APIs */
-(SDK_RESULT_CODES) open;
-(SDK_RESULT_CODES) close;
-(SDK_RESULT_CODES) connectWithTarget:(LabelPrinterObject*)printer timeout:(NSInteger)timeout;
-(SDK_RESULT_CODES) connectWithAddress:(NSString*)address port:(NSString*) port;   // WifiPrinter's IPAddress or BluetoothPrinter's Mac(port is nil)
-(SDK_RESULT_CODES) connectWithSerialNumber:(NSString*)serialNumber;

-(BOOL) isConnected;
-(SDK_RESULT_CODES) disconnect;
-(SDK_RESULT_CODES) disconnectWithTimeout:(NSInteger)timeout;

-(NSInteger)       getDpi;
-(NSInteger)       getMaxWidth;

/**************************************************************************************************
 *  checkStatus
 - call example : [_printer checkPrinterStatus:^(NSInteger status){  NSLog(@"myStatus : %d", status);  }];
 *************************************************************************************************/
-(SDK_RESULT_CODES) checkPrinterStatus:(blockType1)statusReceiver;

- (NSString *) getModelName;

- (NSString *) getFirmwareVersion;

/**************************************************************************************************
 *  Do Print...
 *************************************************************************************************/
-(SDK_RESULT_CODES) doPrint:(NSInteger)numberOfCopies;


/**************************************************************************************************
 *  Print Raw Data...
 *************************************************************************************************/
-(SDK_RESULT_CODES) printRawData:(NSData*)rawData;


/**************************************************************************************************
 *  DrawText
 *************************************************************************************************/
-(SDK_RESULT_CODES) drawTextDeviceFont:(NSString*)text
                                xPosition:(NSInteger)xPostion
                                yPosition:(NSInteger)yPostion
                            fontSelection:(char)fontSelection
                                fontWidth:(NSInteger)fontWidth
                               fontHeight:(NSInteger)fontHeight
                rightSideCharacterSpacing:(NSInteger)rightSideCharacterSpacing
                             fontRotation:(NSInteger)fontRotation
                                  reverse:(BOOL)reverse
                                     bold:(BOOL)bold
                            textAlignment:(NSInteger)textAlignment;

-(SDK_RESULT_CODES) drawTextVectorFont:(NSString*)text
                                xPosition:(NSInteger)xPostion
                                yPosition:(NSInteger)yPostion
                            fontSelection:(char)fontSelection
                                fontWidth:(NSInteger)fontWidth
                               fontHeight:(NSInteger)fontHeight
                rightSideCharacterSpacing:(NSInteger)rightSideCharacterSpacing
                             fontRotation:(NSInteger)fontRotation
                                  reverse:(BOOL)reverse
                                     bold:(BOOL)bold
                                   italic:(BOOL)italic
            textWriteDirectionRightToLeft:(BOOL)textWriteDirectionRightToLeft
                            textAlignment:(NSInteger)textAlignment;


/**************************************************************************************************
 *  Draw 1D Barcode
 *************************************************************************************************/
-(SDK_RESULT_CODES) drawBarcode1D:(NSString*)data
                           xPosition:(NSInteger)xPostion
                           yPosition:(NSInteger)yPostion
                         barcodeType:(NSInteger)barcodeType
                         widthNarrow:(NSInteger)widthNarrow
                           widthWide:(NSInteger)widthWide
                              height:(NSInteger)height
                                 hri:(NSInteger)hri
                      quietZoneWidth:(NSInteger)quietZoneWidth
                            rotation:(NSInteger)rotation;

/**************************************************************************************************
 *  Draw 2D Barcodes
 *************************************************************************************************/
-(SDK_RESULT_CODES) drawBarcodeMaxiCode:(NSString*)data
                                 xPosition:(NSInteger)xPostion
                                 yPosition:(NSInteger)yPostion
                                      mode:(NSInteger)mode;


-(SDK_RESULT_CODES) drawBarcodePDF417:(NSString*)data
                               xPosition:(NSInteger)xPostion
                               yPosition:(NSInteger)yPostion
                         maximumRowCount:(NSInteger)maximumRowCount       // 3~90
                      maximumColumnCount:(NSInteger)maximumColumnCount    // 1~30
                    errorCorrectionLevel:(NSInteger)errorCorrectionLevel
                   dataCompressionMethod:(NSInteger)dataCompressionMethod
                        printBarcodeText:(BOOL)printBarcodeText
                      barcodeOriginPoint:(NSInteger)barcodeOriginPoint
                             moduleWidth:(NSInteger)moduleWidth   // 2~9
                               barHeight:(NSInteger)barHeight     // 4~99
                                rotation:(NSInteger)rotation;


-(SDK_RESULT_CODES) drawBarcodeQRCode:(NSString*)data
                               xPosition:(NSInteger)xPostion
                               yPosition:(NSInteger)yPostion
                             barcodeSize:(NSInteger)barcodeSize   // 1~4
                                   model:(NSInteger)model
                     errorColectionLevel:(NSInteger)errorColectionLevel
                                rotation:(NSInteger)rotation;

-(SDK_RESULT_CODES) drawBarcodeDataMatrix:(NSString*)data
                                   xPosition:(NSInteger)xPostion
                                   yPosition:(NSInteger)yPostion
                                 barcodeSize:(NSInteger)barcodeSize   // 1~4
                                     reverse:(BOOL)reverse
                                    rotation:(NSInteger)rotation;

-(SDK_RESULT_CODES) drawBarcodeAztec:(NSString*)data
                              xPosition:(NSInteger)xPostion
                              yPosition:(NSInteger)yPostion
                            barcodeSize:(NSInteger)barcodeSize    // 1~10
                        extendedChannel:(BOOL)extendedChannel
                   errorCorrectionLevel:(NSInteger)errorCorrectionLevel
                             menuSymbol:(BOOL)menuSymbol
                        numberOfSymbols:(NSInteger)numberOfSymbols
                             optionalID:(NSString*)optionalID
                               rotation:(NSInteger)rotation;

-(SDK_RESULT_CODES)drawBarcodeCode49:(NSString*)data
                              xPosition:(NSInteger)xPostion
                              yPosition:(NSInteger)yPostion
                            widthNarrow:(NSInteger)widthNarrow
                              widthWide:(NSInteger)widthWide
                                 height:(NSInteger)height
                                    hri:(NSInteger)hri
                           startingMode:(NSInteger)startingMode
                               rotation:(NSInteger)rotation;

-(SDK_RESULT_CODES) drawBarcodeCodaBlock:(NSString*)data
                                  xPosition:(NSInteger)xPostion
                                  yPosition:(NSInteger)yPostion
                                widthNarrow:(NSInteger)widthNarrow
                                  widthWide:(NSInteger)widthWide
                                     height:(NSInteger)height
                              securityLevel:(BOOL)securityLevel
                   numberOfCharactersPerrow:(NSInteger)numberOfCharactersPerrow    //  2~62
                                       mode:(char)mode
                        numberOfRowToEncode:(NSInteger)numberOfRowToEncode;  //  'modeA' : 1~18  else 2~4

-(SDK_RESULT_CODES) drawBarcodeMicroPDF:(NSString*)data
                                 xPosition:(NSInteger)xPostion
                                 yPosition:(NSInteger)yPostion
                               moduleWidth:(NSInteger)moduleWidth     // 2~8
                             barcodeHeight:(NSInteger)barcodeHeight   // 1~99
                                      mode:(NSInteger)mode            // 0~33
                                  rotation:(NSInteger)rotation;


/**************************************************************************************************
 *  Draw Special Barcode
 *************************************************************************************************/
-(SDK_RESULT_CODES) drawBarcodeIMB:(NSString*)data
                            xPosition:(NSInteger)xPostion
                            yPosition:(NSInteger)yPostion
                     printBarcodeText:(BOOL)printBarcodeText
                             rotation:(NSInteger)rotation;

-(SDK_RESULT_CODES) drawBarcodeMSI:(NSString*)data
                            xPosition:(NSInteger)xPostion
                            yPosition:(NSInteger)yPostion
                          widthNarrow:(NSInteger)widthNarrow
                            widthWide:(NSInteger)widthWide
                               height:(NSInteger)height
                  checkDigitSelection:(NSInteger)checkDigitSelection
                 printCheckDigitInHRI:(BOOL)printCheckDigitInHRI
                                  hri:(NSInteger)hri
                             rotation:(NSInteger)rotation;


-(SDK_RESULT_CODES) drawBarcodePlessey:(NSString*)data
                                xPosition:(NSInteger)xPostion
                                yPosition:(NSInteger)yPostion
                              widthNarrow:(NSInteger)widthNarrow
                                widthWide:(NSInteger)widthWide
                                   height:(NSInteger)height
                          printCheckDigit:(BOOL)printCheckDigit
                                      hri:(NSInteger)hri
                                 rotation:(NSInteger)rotation;

-(SDK_RESULT_CODES) drawBarcodeTLC39:(NSString*)data
                              xPosition:(NSInteger)xPostion
                              yPosition:(NSInteger)yPostion
                            widthNarrow:(NSInteger)widthNarrow
                              widthWide:(NSInteger)widthWide
                                 height:(NSInteger)height
                 rowHeightOfMicroPDF417:(NSInteger)rowHeightOfMicroPDF417
               narrowWidthOfMicroPDF417:(NSInteger)narrowWidthOfMicroPDF417
                               rotation:(NSInteger)rotation;

-(SDK_RESULT_CODES) drawBarcodeRSS:(NSString*)data
                            xPosition:(NSInteger)xPostion
                            yPosition:(NSInteger)yPostion
                          barcodeType:(NSInteger)barcodeType
                        magnification:(NSInteger)magnification   // 1~10
                      separatorHeight:(NSInteger)separatorHeight // 1~2
                        barcodeHeight:(NSInteger)barcodeHeight   //  This parameter only affects the UCC/EAN barcode type and CC-A/B/C barcode Type.
                         segmentWidth:(NSInteger)segmentWidth    // 0~22
                             rotation:(NSInteger)rotation;

-(SDK_RESULT_CODES) drawBlock:(NSInteger)startPosX
                       startPosY:(NSInteger)startPosY
                         endPosX:(NSInteger)endPosX
                         endPosY:(NSInteger)endPosY
                          option:(char)option
                       thickness:(NSInteger)thickness;


-(SDK_RESULT_CODES) drawCircle:(NSInteger)startPosX
                        startPosY:(NSInteger)startPosY
                    sizeSelection:(NSInteger)sizeSelection
                       multiplier:(NSInteger)multiplier;

-(SDK_RESULT_CODES) drawImageData:(UIImage *)image
                       stratPosX:(NSInteger)startPosX
                       startPosY:(NSInteger)startPosY
                           width:(NSInteger)width
                    useDithering:(BOOL)useDithering;

-(SDK_RESULT_CODES) setOrientation:(NSInteger)orientation;

#pragma mark - about setting
///
-(SDK_RESULT_CODES) setICS:(NSInteger)ics codepage:(NSInteger)cp;

// __SDK_SPEED_VALUE reference in LabelPrinterSDK_Defines.h
-(SDK_RESULT_CODES) setSpeed:(NSInteger) speedValue;

-(SDK_RESULT_CODES) setDensity:(NSInteger) densityValue;  //  0~20

// __SDK_MEDIA_TYPE reference in LabelPrinterSDK_Defines.h
-(SDK_RESULT_CODES) setLength:(NSInteger) labelLength
                       gapLength:(NSInteger) gapLength
                       mediaType:(char) mediaType
                    offsetLength:(NSInteger)offsetLength;

-(SDK_RESULT_CODES) setMargin:(NSInteger)horizontalMargin
                  verticalMargin:(NSInteger)verticalMargin;

-(SDK_RESULT_CODES) setOffset:(NSInteger)offsetValue; //  -100 ~ 100

-(SDK_RESULT_CODES) setCuttingPosition:(NSInteger)cuttiongPosition;  //  -100 ~ 100

-(SDK_RESULT_CODES) setWidth:(NSInteger) widthValue;

@end


