
import UIKit

class BaseViewController: UIViewController {

    @IBOutlet weak var scr:UIScrollView?
    
    private var tapGesture:UITapGestureRecognizer?
    
    override func viewWillAppear(_ animated: Bool) {
        SharedLabelPrinterSDK.sdk.delegate = self
    }

    override func viewDidLoad() {
        super.viewDidLoad()
        
        NotificationCenter.default.addObserver(self,
                                               selector: #selector(keyboardWillShow(notification:)),
                                               name: UIResponder.keyboardWillShowNotification,
                                               object: nil)
        NotificationCenter.default.addObserver(self,
                                               selector: #selector(keyboardWillHide(notification:)),
                                               name: UIResponder.keyboardWillHideNotification,
                                               object: nil)
    }
    
    @objc func forceEndInput() {
        self.view.endEditing(false)
    }
    
    @objc func keyboardWillShow(notification:Notification) {
        if let rectValue = notification.userInfo?[UIResponder.keyboardFrameEndUserInfoKey] as? NSValue {
            scr?.contentInset = .init(top: 0, left: 0, bottom: rectValue.cgRectValue.height, right: 0)
        }
        
        if tapGesture != nil,
            view.gestureRecognizers?.contains(tapGesture!) == true {
            view.removeGestureRecognizer(tapGesture!)
        }
        
        tapGesture = UITapGestureRecognizer(target: self, action: #selector(forceEndInput))
        self.view.addGestureRecognizer(tapGesture!)
    }
    
    @objc func keyboardWillHide(notification:Notification) {
        scr?.contentInset = .init(top: 0, left: 0, bottom: 0, right: 0)
        
        if tapGesture != nil,
            view.gestureRecognizers?.contains(tapGesture!) == true {
            view.removeGestureRecognizer(tapGesture!)
        }
    }
    
    func presentTextAlert(title:String? = nil, msg:String? = nil) {
        let alert = UIAlertController(title: title, message: msg, preferredStyle: .alert)
        alert.addAction(.init(title: "OK", style: .default, handler: nil))
        present(alert, animated: true, completion: nil)
    }
}

extension BaseViewController : UITextFieldDelegate {
    
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        textField.resignFirstResponder()
        return true
    }
}

// MARK: - LabelPrinterSDKDelegate
extension BaseViewController : LabelPrinterSDKDelegate {
    func willConnect(_ controller: LabelPrinterSDK!, printer: LabelPrinterObject!) {
    }
    
    func didConnect(_ controller: LabelPrinterSDK!, printer: LabelPrinterObject!) {
    }
    
    func didNotConnect(_ controller: LabelPrinterSDK!, printer: LabelPrinterObject!, withError error: Error!) {
    }
    
    func didDisconnect(_ controller: LabelPrinterSDK!, printer: LabelPrinterObject!) {
    }
    
    func didBeBrokenConnection(_ controller: LabelPrinterSDK!, printer: LabelPrinterObject!, withError error: Error!) {
        let controller = UIAlertController(title: nil, message: "Printer Disconnect", preferredStyle: .alert)
        controller.addAction(.init(title: "OK", style: .default, handler: { [weak self] (_) in
            self?.navigationController?.popToRootViewController(animated: true)
        }))
        self.present(controller, animated: true, completion: nil)
    }
    
    func willLookupPrinter(_ controller: LabelPrinterSDK!) {
    }
    
    func didFindPrinter(_ controller: LabelPrinterSDK!, printer: LabelPrinterObject!) {
    }
    
    func didLookupPrinters(_ controller: LabelPrinterSDK!, printerList: [Any]!) {
    }
    
    func canNotFoundPrinter() {
    }
}
