
import UIKit

class Draw1DBarcodeViewController: BaseViewController {
    
    @IBOutlet weak var tfText:UITextField!
    @IBOutlet weak var tfXpos:UITextField!
    @IBOutlet weak var tfYpos:UITextField!
    @IBOutlet weak var tfNarrow:UITextField!
    @IBOutlet weak var tfWide:UITextField!
    @IBOutlet weak var tfHeight:UITextField!
    
    @IBOutlet weak var btnBarcode:UIButton!
    @IBOutlet weak var btnBarcodeHRI:UIButton!
    @IBOutlet weak var segRotation:UISegmentedControl!
    
    let printer = SharedLabelPrinterSDK.sdk
    
    var barcodeList:[(value:SDK_BARCODE_TYPE, description:String)] = [
        (._CODE39, "CODE39"),
        (._CODE128 , "CODE128"),
        (._I2Of5 , "I2Of5"),
        (._CODABAR , "CODABAR"),
        (._CODE93 , "CODE93"),
        (._UPC_A , "UPC_A"),
        (._UPC_E , "UPC_E"),
        (._EAN13 , "EAN13"),
        (._EAN8 , "EAN8"),
        (._EAN128 , "EAN128"),
        (._CODE11 , "CODE11"),
        (._PLANET , "PLANET"),
        (._INDUSTRIAL_2Of5 , "INDUSTRIAL_2Of5"),
        (._STANDARD_2Of5 , "STANDARD_2Of5"),
        (._LOGMARS , "LOGMARS"),
        (._UPC_EAN_EXTENSIONS , "UPC_EAN_EXTENSIONS"),
        (._POSTNET , "POSTNET")
    ]
    
    var barcodeHriList:[(value:SDK_BARCODE_HRI, description:String)] = [
        (.NONE , "NONE"),
        (.BELOW_FONTSIZE1 , "BELOW_FONTSIZE1"),
        (.ABOVE_FONTSIZE1 , "ABOVE_FONTSIZE1"),
        (.BELOW_FONTSIZE2 , "BELOW_FONTSIZE2"),
        (.ABOVE_FONTSIZE2 , "ABOVE_FONTSIZE2"),
        (.BELOW_FONTSIZE3 , "BELOW_FONTSIZE3"),
        (.ABOVE_FONTSIZE3 , "ABOVE_FONTSIZE3"),
        (.BELOW_FONTSIZE4 , "BELOW_FONTSIZE4"),
        (.ABOVE_FONTSIZE4 , "ABOVE_FONTSIZE4")
    ]
    
    lazy var currentBarcode = barcodeList.first
    lazy var currentBarcodeHRI = barcodeHriList.first
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        btnBarcode.setTitle(currentBarcode?.description, for: .normal)
        btnBarcodeHRI.setTitle(currentBarcodeHRI?.description, for: .normal)
    }
    
    @IBAction func selectBarcode(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for barcode in barcodeList {
            controller.addAction(.init(title: barcode.description, style: .default, handler: { [weak self] _ in
                self?.btnBarcode.setTitle(barcode.description, for: .normal)
                self?.currentBarcode = barcode
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func selectBarcodeHri(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for hri in barcodeHriList {
            controller.addAction(.init(title: hri.description, style: .default, handler: { [weak self] _ in
                self?.btnBarcodeHRI.setTitle(hri.description, for: .normal)
                self?.currentBarcodeHRI = hri
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func print(_ sender:UIButton) {
        let text = tfText.text ?? ""
        let xPos = Int(tfXpos.text ?? "0") ?? 0
        let yPos = Int(tfYpos.text ?? "0") ?? 0
        let barcodeType = (currentBarcode?.value ?? ._CODE128).rawValue
        let narrow = Int(tfNarrow.text ?? "0") ?? 0
        let wide = Int(tfWide.text ?? "0") ?? 0
        let height = Int(tfHeight.text ?? "0") ?? 0
        let hri = (currentBarcodeHRI?.value ?? .NONE).rawValue
        
        let rotation:Int
        switch segRotation.selectedSegmentIndex {
        case 0: rotation = SDK_ROTATION_DEGREES._0.rawValue
        case 1: rotation = SDK_ROTATION_DEGREES._90.rawValue
        case 2: rotation = SDK_ROTATION_DEGREES._180.rawValue
        case 3: rotation = SDK_ROTATION_DEGREES._270.rawValue
        default:
            rotation = SDK_ROTATION_DEGREES._0.rawValue
        }
        
        var result = printer.drawBarcode1D(text,
                                           xPosition: xPos,
                                           yPosition: yPos,
                                           barcodeType: barcodeType,
                                           widthNarrow: narrow,
                                           widthWide: wide,
                                           height: height,
                                           hri: hri,
                                           quietZoneWidth: 0,
                                           rotation: rotation)
        
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Draw Fail")
            return
        }

        result = printer.doPrint(1)
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Print Fail")
            return
        }
    }
}
