
import UIKit

class DrawBlockViewController: BaseViewController {
    
    @IBOutlet weak var tfStartXpos:UITextField!
    @IBOutlet weak var tfStartYpos:UITextField!
    @IBOutlet weak var tfEndXpos:UITextField!
    @IBOutlet weak var tfEndYpos:UITextField!
    @IBOutlet weak var tfThickness:UITextField!
    
    @IBOutlet weak var btnType:UIButton!
    
    let printer = SharedLabelPrinterSDK.sdk
    
    let typeList:[(value:SDK_DRAW_BLOCK_OPTION, description:String)] = [
        (.LINE_OVERWRITING, "Line over writing"),
        (.LINE_EXCLUSIVE_OR, "Line exclusive or"),
        (.LINE_DELETE, "Line delete"),
        (.SLOPE, "Slope"),
        (.BOX, "BOX")
    ]
    
    lazy var currentType = typeList.first
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        btnType.setTitle(currentType?.description, for: .normal)
    }
    
    @IBAction func selectType(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for type in typeList {
            controller.addAction(.init(title: type.description, style: .default, handler: { [weak self] _ in
                self?.btnType.setTitle(type.description, for: .normal)
                self?.currentType = type
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func print(_ sender:UIButton) {
        let startXpos = Int(tfStartXpos.text ?? "0") ?? 0
        let startYpos = Int(tfStartYpos.text ?? "0") ?? 0
        
        let endXpos = Int(tfEndXpos.text ?? "0") ?? 0
        let endYpos = Int(tfEndYpos.text ?? "0") ?? 0
        
        let thickness = Int(tfThickness.text ?? "0") ?? 0
        let option = (currentType?.value ?? .LINE_OVERWRITING).rawValue
        
        var result = printer.drawBlock(startXpos,
                                       startPosY: startYpos,
                                       endPosX: endXpos,
                                       endPosY: endYpos,
                                       option: option,
                                       thickness: thickness)
        
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Draw Fail")
            return
        }

        result = printer.doPrint(1)
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Print Fail")
            return
        }
    }
}
