
import UIKit

class DrawCircleViewController: BaseViewController {

    @IBOutlet weak var tfXpos:UITextField!
    @IBOutlet weak var tfYpos:UITextField!
    @IBOutlet weak var tfMultiplier:UITextField!
    
    @IBOutlet weak var btnSize:UIButton!
    
    let printer = SharedLabelPrinterSDK.sdk
    
    let sizeList:[(value:SDK_DRAW_CIRCLE_SIZE, description:String)] = [
        (._40X40, "40x40"),
        (._56X56, "56x56"),
        (._72X72, "72x72"),
        (._88X88, "88x88"),
        (._104X104, "104x104"),
        (._168X168, "168x168")
    ]
    
    lazy var currentSize = sizeList.first
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        btnSize.setTitle(currentSize?.description, for: .normal)
    }
    
    @IBAction func selectSize(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for size in sizeList {
            controller.addAction(.init(title: size.description, style: .default, handler: { [weak self] _ in
                self?.btnSize.setTitle(size.description, for: .normal)
                self?.currentSize = size
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func print(_ sender:UIButton) {
        let startXpos = Int(tfXpos.text ?? "0") ?? 0
        let startYpos = Int(tfYpos.text ?? "0") ?? 0
        
        let multiplier = Int(tfMultiplier.text ?? "0") ?? 0

        let sizeSelection = (currentSize?.value ?? SDK_DRAW_CIRCLE_SIZE._40X40).rawValue
        
        var result = printer.drawCircle(startXpos,
                           startPosY: startYpos,
                           sizeSelection: sizeSelection,
                           multiplier: multiplier)
        
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Draw Fail")
            return
        }

        result = printer.doPrint(1)
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Print Fail")
            return
        }
    }
}
