
import UIKit

class DrawDeviceFontViewController: BaseViewController {
    
    @IBOutlet weak var tfText:UITextField!
    @IBOutlet weak var tfXpos:UITextField!
    @IBOutlet weak var tfYpos:UITextField!
    @IBOutlet weak var tfRightSpace:UITextField!
    
    @IBOutlet weak var btnFont:UIButton!
    @IBOutlet weak var tfHorizontalMulti:UITextField!
    @IBOutlet weak var tfVerticalMulti:UITextField!
    @IBOutlet weak var segRotation:UISegmentedControl!
    @IBOutlet weak var segAlignment:UISegmentedControl!
    @IBOutlet weak var segReverse:UISegmentedControl!
    @IBOutlet weak var segBold:UISegmentedControl!
    
    let printer = SharedLabelPrinterSDK.sdk
    
    let fontList:[(value:SDK_DEVICE_FONT, description:String)] = [
        (._6PT, "DEVICE_FONT_6PT"),
        (._8PT, "DEVICE_FONT_8PT"),
        (._10PT, "DEVICE_FONT_10PT"),
        (._12PT, "DEVICE_FONT_12PT"),
        (._15PT, "DEVICE_FONT_15PT"),
        (._20PT, "DEVICE_FONT_20PT"),
        (._30PT, "DEVICE_FONT_30PT"),
        (._14PT, "DEVICE_FONT_14PT"),
        (._18PT, "DEVICE_FONT_18PT"),
        (._24PT, "DEVICE_FONT_24PT"),
        (._KOREAN1, "DEVICE_FONT_KOREAN1"),
        (._KOREAN2, "DEVICE_FONT_KOREAN2"),
        (._KOREAN3, "DEVICE_FONT_KOREAN3"),
        (._KOREAN4, "DEVICE_FONT_KOREAN4"),
        (._KOREAN5, "DEVICE_FONT_KOREAN5"),
        (._KOREAN6, "DEVICE_FONT_KOREAN6"),
        (._GB2312, "DEVICE_FONT_GB2312"),
        (._BIG5, "DEVICE_FONT_BIG5"),
        (._SHIFT_JIS, "DEVICE_FONT_SHIFT_JIS")
        
    ]
    
    lazy var currentFont = fontList.first
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        btnFont.setTitle(currentFont?.description, for: .normal)
    }
    
    @IBAction func selectFont(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for font in fontList {
            controller.addAction(.init(title: font.description, style: .default, handler: { [weak self] _ in
                self?.btnFont.setTitle(font.description, for: .normal)
                self?.currentFont = font
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func print(_ sender:UIButton) {
        let text = tfText.text ?? ""
        let xPos = Int(tfXpos.text ?? "0") ?? 0
        let yPos = Int(tfYpos.text ?? "0") ?? 0
        let font = (currentFont?.value ?? ._6PT).rawValue
        let width = Int(tfHorizontalMulti.text ?? "0") ?? 0
        let height = Int(tfVerticalMulti.text ?? "0") ?? 0
        let rightSpacing = Int(tfRightSpace.text ?? "0") ?? 0
        
        let fontRotation:Int
        switch segRotation.selectedSegmentIndex {
        case 0: fontRotation = SDK_ROTATION_DEGREES._0.rawValue
        case 1: fontRotation = SDK_ROTATION_DEGREES._90.rawValue
        case 2: fontRotation = SDK_ROTATION_DEGREES._180.rawValue
        case 3: fontRotation = SDK_ROTATION_DEGREES._270.rawValue
        default:
            fontRotation = SDK_ROTATION_DEGREES._0.rawValue
        }
        
        let alignment:Int
        switch segAlignment.selectedSegmentIndex {
        case 0: alignment = SDK_ALIGNMENT.LEFT.rawValue
        case 1: alignment = SDK_ALIGNMENT.RIGHT.rawValue
        case 2: alignment = SDK_ALIGNMENT.STRING_FROM_RIGHT_2_LEFT.rawValue
        default:
            alignment = SDK_ALIGNMENT.LEFT.rawValue
        }
        
        let reverse = segReverse.selectedSegmentIndex == 1
        let bold = segBold.selectedSegmentIndex == 1

        var result = printer.drawTextDeviceFont(text,
                                   xPosition: xPos,
                                   yPosition: yPos,
                                   fontSelection: font,
                                   fontWidth: width,
                                   fontHeight: height,
                                   rightSideCharacterSpacing: rightSpacing,
                                   fontRotation: fontRotation,
                                   reverse: reverse,
                                   bold: bold,
                                   textAlignment: alignment)
        
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Draw Fail")
            return
        }

        result = printer.doPrint(1)
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Print Fail")
            return
        }
    }
}
