
import UIKit

class DrawMaxiCodeViewController: BaseViewController {
    
    @IBOutlet weak var tfText:UITextField!
    @IBOutlet weak var tfXpos:UITextField!
    @IBOutlet weak var tfYpos:UITextField!
    
    @IBOutlet weak var btnMode:UIButton!
    
    let printer = SharedLabelPrinterSDK.sdk
    
    let barcodeList:[(mode:SDK_MAXICODE_MODE, description:String)] = [
        (._0, "Mode 0"),
        (._2, "Mode 2"),
        (._3, "Mode 3"),
        (._4, "Mode 4")
    ]
    
    lazy var currentBarcode = barcodeList.first
    
    override func viewDidLoad() {
        super.viewDidLoad()
        btnMode.setTitle(currentBarcode?.description, for: .normal)
    }
    
    @IBAction func selectMode(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for barcode in barcodeList {
            controller.addAction(.init(title: barcode.description, style: .default, handler: { [weak self] _ in
                self?.btnMode.setTitle(barcode.description, for: .normal)
                self?.currentBarcode = barcode
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func print(_ sender:UIButton) {
        let text = tfText.text ?? ""
        let xPos = Int(tfXpos.text ?? "0") ?? 0
        let yPos = Int(tfYpos.text ?? "0") ?? 0
        let mode = (currentBarcode?.mode ?? ._0).rawValue
        
        var result = printer.drawBarcodeMaxiCode(text,
                                                 xPosition: xPos,
                                                 yPosition: yPos,
                                                 mode: mode)

        guard result == .SUCCESS else {
            presentTextAlert(msg: "Draw Fail")
            return
        }

        result = printer.doPrint(1)
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Print Fail")
            return
        }
    }
}
