

import UIKit

class DrawPDF417ViewController: BaseViewController {
    
    @IBOutlet weak var tfText:UITextField!
    @IBOutlet weak var tfXpos:UITextField!
    @IBOutlet weak var tfYpos:UITextField!
    @IBOutlet weak var tfRowCount:UITextField!
    @IBOutlet weak var tfColumnCount:UITextField!
    
    @IBOutlet weak var tfWidth:UITextField!
    @IBOutlet weak var tfHeight:UITextField!
    
    @IBOutlet weak var btnErrorCorrectionLevel:UIButton!
    
    @IBOutlet weak var segDataCompressionMethod:UISegmentedControl!
    @IBOutlet weak var segBarcodeText:UISegmentedControl!
    @IBOutlet weak var segOriginPoint:UISegmentedControl!
    @IBOutlet weak var segRotation:UISegmentedControl!

    let printer = SharedLabelPrinterSDK.sdk
    
    let errorCorrectionLevelList:[(mode:SDK_ERROR_CORRECTION_LEVEL, description:String)] = [
        (.LEVEL0, "LEVEL 0"),
        (.LEVEL1, "LEVEL 1"),
        (.LEVEL2, "LEVEL 2"),
        (.LEVEL3, "LEVEL 3"),
        (.LEVEL4, "LEVEL 4"),
        (.LEVEL5, "LEVEL 5"),
        (.LEVEL6, "LEVEL 6"),
        (.LEVEL7, "LEVEL 7"),
        (.LEVEL8, "LEVEL 8")
    ]
    lazy var currentErrLevel = errorCorrectionLevelList.first
    
    override func viewDidLoad() {
        super.viewDidLoad()
        btnErrorCorrectionLevel.setTitle(currentErrLevel?.description, for: .normal)
    }
    
    @IBAction func selectErrorLevel(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for err in errorCorrectionLevelList {
            controller.addAction(.init(title: err.description, style: .default, handler: { [weak self] _ in
                self?.btnErrorCorrectionLevel.setTitle(err.description, for: .normal)
                self?.currentErrLevel = err
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func print(_ sender:UIButton) {
        let text = tfText.text ?? ""
        let xPos = Int(tfXpos.text ?? "0") ?? 0
        let yPos = Int(tfYpos.text ?? "0") ?? 0
        let rowCount = Int(tfRowCount.text ?? "0") ?? 0
        let columnCount = Int(tfColumnCount.text ?? "0") ?? 0
        let moduleWidth = Int(tfWidth.text ?? "0") ?? 0
        let barHeight = Int(tfHeight.text ?? "0") ?? 0
        let errorCorrectionLevel = Int((currentErrLevel?.mode ?? .LEVEL0).rawValue)
        let dataCompressionMethod:Int
        switch segDataCompressionMethod.selectedSegmentIndex {
        case 0: dataCompressionMethod = SDK_DATA_COMPRESSION_METHOD.TEXT.rawValue
        case 1: dataCompressionMethod = SDK_DATA_COMPRESSION_METHOD.NUMERIC.rawValue
        case 2: dataCompressionMethod = SDK_DATA_COMPRESSION_METHOD.BINARY.rawValue
        default: dataCompressionMethod = SDK_DATA_COMPRESSION_METHOD.TEXT.rawValue
        }
        
        let printBarcodeText = segBarcodeText.selectedSegmentIndex == 1
        let originPoint = (segOriginPoint.selectedSegmentIndex == 1 ? SDK_BARCODE_ORIGIN_POINT.CENTER : SDK_BARCODE_ORIGIN_POINT.UPPER_LEFT).rawValue
                
        let rotation:Int
        switch segRotation.selectedSegmentIndex {
        case 0: rotation = SDK_ROTATION_DEGREES._0.rawValue
        case 1: rotation = SDK_ROTATION_DEGREES._90.rawValue
        case 2: rotation = SDK_ROTATION_DEGREES._180.rawValue
        case 3: rotation = SDK_ROTATION_DEGREES._270.rawValue
        default:
            rotation = SDK_ROTATION_DEGREES._0.rawValue
        }
        
        var result = printer.drawBarcodePDF417(text,
                                               xPosition: xPos,
                                               yPosition: yPos,
                                               maximumRowCount: rowCount,
                                               maximumColumnCount: columnCount,
                                               errorCorrectionLevel: errorCorrectionLevel,
                                               dataCompressionMethod: dataCompressionMethod,
                                               printBarcodeText: printBarcodeText,
                                               barcodeOriginPoint: originPoint,
                                               moduleWidth: moduleWidth,
                                               barHeight: barHeight,
                                               rotation: rotation)
        
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Draw Fail")
            return
        }

        result = printer.doPrint(1)
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Print Fail")
            return
        }
    }
    
}
