
import UIKit

class DrawQRCodeViewController: BaseViewController {
    
    @IBOutlet weak var tfText:UITextField!
    @IBOutlet weak var tfXpos:UITextField!
    @IBOutlet weak var tfYpos:UITextField!
    @IBOutlet weak var tfSize:UITextField!
    
    @IBOutlet weak var segModel:UISegmentedControl!
    @IBOutlet weak var segECC:UISegmentedControl!
    @IBOutlet weak var segRotation:UISegmentedControl!

    let printer = SharedLabelPrinterSDK.sdk
    
    override func viewDidLoad() {
        super.viewDidLoad()
    }
    
    @IBAction func print(_ sender:UIButton) {
        let text = tfText.text ?? ""
        let xPos = Int(tfXpos.text ?? "0") ?? 0
        let yPos = Int(tfYpos.text ?? "0") ?? 0
        let size = Int(tfSize.text ?? "0") ?? 0
        
        let model = (segModel.selectedSegmentIndex == 1 ? SDK_QRCODE_MODE.MODEL_2 : SDK_QRCODE_MODE.MODEL_1).rawValue
        let ecc = segECC.selectedSegmentIndex
        
        let rotation:Int
        switch segRotation.selectedSegmentIndex {
        case 0: rotation = SDK_ROTATION_DEGREES._0.rawValue
        case 1: rotation = SDK_ROTATION_DEGREES._90.rawValue
        case 2: rotation = SDK_ROTATION_DEGREES._180.rawValue
        case 3: rotation = SDK_ROTATION_DEGREES._270.rawValue
        default:
            rotation = SDK_ROTATION_DEGREES._0.rawValue
        }
        
        var result = printer.drawBarcodeQRCode(text,
                                               xPosition: xPos,
                                               yPosition: yPos,
                                               barcodeSize: size,
                                               model: model,
                                               errorColectionLevel: ecc,
                                               rotation: rotation)
        
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Draw Fail")
            return
        }

        result = printer.doPrint(1)
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Print Fail")
            return
        }
    }
    
}
