
import UIKit

class DrawVectorFontViewController: BaseViewController {
    
    @IBOutlet weak var tfText:UITextField!
    @IBOutlet weak var tfXpos:UITextField!
    @IBOutlet weak var tfYpos:UITextField!
    @IBOutlet weak var tfRightSpace:UITextField!
    
    @IBOutlet weak var btnFont:UIButton!
    @IBOutlet weak var tfWidth:UITextField!
    @IBOutlet weak var tfHeight:UITextField!
    @IBOutlet weak var segRotation:UISegmentedControl!
    @IBOutlet weak var segAlignment:UISegmentedControl!
    @IBOutlet weak var segWriteDirection:UISegmentedControl!
    @IBOutlet weak var segReverse:UISegmentedControl!
    @IBOutlet weak var segBold:UISegmentedControl!
    @IBOutlet weak var segItalic:UISegmentedControl!
    
    let printer = SharedLabelPrinterSDK.sdk
    
    let fontList:[(value:SDK_VECTOR_FONT, description:String)] = [
        (.ASCII, "ASCII"),
        (.BIG5, "BIG5"),
        (.GB2312, "GB2312"),
        (.SHIFT_JIS, "SHIFT_JIS"),
        (.OCR_A, "OCR_A"),
        (.OCR_B, "OCR_B")
    ]
    
    lazy var currentFont = fontList.first
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        btnFont.setTitle(currentFont?.description, for: .normal)
    }
    
    @IBAction func selectFont(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for font in fontList {
            controller.addAction(.init(title: font.description, style: .default, handler: { [weak self] _ in
                self?.btnFont.setTitle(font.description, for: .normal)
                self?.currentFont = font
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func print(_ sender:UIButton) {
        let text = tfText.text ?? ""
        let xPos = Int(tfXpos.text ?? "0") ?? 0
        let yPos = Int(tfYpos.text ?? "0") ?? 0
        let font = (currentFont?.value ?? .ASCII).rawValue
        let width = Int(tfWidth.text ?? "0") ?? 0
        let height = Int(tfHeight.text ?? "0") ?? 0
        let rightSpacing = Int(tfRightSpace.text ?? "0") ?? 0
        
        let fontRotation:Int
        switch segRotation.selectedSegmentIndex {
        case 0: fontRotation = Int(SDK_ROTATION_DEGREES._0.rawValue)
        case 1: fontRotation = Int(SDK_ROTATION_DEGREES._90.rawValue)
        case 2: fontRotation = Int(SDK_ROTATION_DEGREES._180.rawValue)
        case 3: fontRotation = Int(SDK_ROTATION_DEGREES._270.rawValue)
        default:
            fontRotation = Int(SDK_ROTATION_DEGREES._0.rawValue)
        }
        
        let alignment:Int
        switch segAlignment.selectedSegmentIndex {
        case 0: alignment = Int(SDK_ALIGNMENT.LEFT.rawValue)
        case 1: alignment = Int(SDK_ALIGNMENT.RIGHT.rawValue)
        case 2: alignment = Int(SDK_ALIGNMENT.CENTER.rawValue)
        default:
            alignment = Int(SDK_ALIGNMENT.LEFT.rawValue)
        }
        
        let reverse = segReverse.selectedSegmentIndex == 1
        let bold = segBold.selectedSegmentIndex == 1
        let itatlic = segItalic.selectedSegmentIndex == 1
        let r2l = segWriteDirection.selectedSegmentIndex == 1
        
        var result = printer.drawTextVectorFont(text,
                                                xPosition: xPos,
                                                yPosition: yPos,
                                                fontSelection: font,
                                                fontWidth: width,
                                                fontHeight: height,
                                                rightSideCharacterSpacing: rightSpacing,
                                                fontRotation: fontRotation,
                                                reverse: reverse,
                                                bold: bold,
                                                italic: itatlic,
                                                textWriteDirectionRightToLeft: r2l,
                                                textAlignment: alignment)
        
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Draw Fail")
            return
        }

        result = printer.doPrint(1)
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Print Fail")
            return
        }
    }
}
