
import UIKit

class SetCharacterSetViewController: BaseViewController {

    let printer = SharedLabelPrinterSDK.sdk
    
    let icsList:[(value:SDK_CONFIG_ICS, description:String)] = [
        (.USA, "U.S.A"),
        (.FRANCE, "France"),
        (.GERMANY, "Germany"),
        (.UK, "U.K"),
        (.DENMARK_I, "Denmark I"),
        (.SWEDEN, "Sweden"),
        (.ITALY, "Italy"),
        (.SPAIN_I, "Spain I"),
        (.NORWAY, "Norway"),
        (.DENMARK_II, "Denmark II"),
        (.JAPAN, "Japan"),
        (.SPAIN_II, "Spain II"),
        (.LATIN_AMERICA, "Latin America"),
        (.KOREA, "Korea"),
        (.SLOVENIA_CROATIA, "Slovenia/Croatia"),
        (.CHINA, "China")
    ]
    
    let codePageList:[(value:SDK_CONFIG_CODEPAGE, description:String)] = [
        (._CP437, "PC437 - USA"),
        (._CP850, "PC850 - Latin 1"),
        (._CP852, "PC852 - Latin 2"),
        (._CP860, "PC860 - Portuguese"),
        (._CP863, "PC863 - Canadian French"),
        (._CP865, "PC865 - Nordic"),
        (._CP1252, "WPC1252 - Latin 1"),
        (._CP865, "PC865 + WPC1252 - European Combined"),
        (._CP857, "PC857 - Turkish"),
        (._CP737, "PC737 - Greek"),
        (._WCP1250, "WPC1250 - Latin 2"),
        (._WCP1253, "WPC1253 - Greek"),
        (._WCP1254, "WPC1254 - Turkish"),
        (._CP855, "PC855 - Cyrillic"),
        (._CP862, "PC862 - Hebrew"),
        (._CP866, "PC866 - Cyrillic"),
        (._WCP1251, "WPC1251 - Cyrillic"),
        (._WCP1255, "WPC1255 - Hebrew"),
        (._CP928, "PC928 - Greek"),
        (._CP864, "PC864 - Arabic"),
        (._CP775, "PC775 - Baltic Dos"),
        (._WCP1257, "WPC1257 - Baltic Windows"),
        (._CP858, "PC858 - Latin 1 + Euro")
    ]
    
    @IBOutlet weak var btnICS:UIButton!
    @IBOutlet weak var btnCodePage:UIButton!
    
    lazy var currentICS = icsList.first
    lazy var currentCodePage = codePageList.first
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view.
        
        btnICS.setTitle(currentICS?.description, for: .normal)
        btnCodePage.setTitle(currentCodePage?.description, for: .normal)
    }
    
    @IBAction func setICS(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for ics in icsList {
            controller.addAction(.init(title: ics.description, style: .default, handler: { [weak self] _ in
                self?.btnICS.setTitle(ics.description, for: .normal)
                self?.currentICS = ics
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func setCodePage(_ sender:UIButton) {
        let controller = UIAlertController(title: nil, message: nil, preferredStyle: .actionSheet)
        for codePage in codePageList {
            controller.addAction(.init(title: codePage.description, style: .default, handler: { [weak self] _ in
                self?.btnCodePage.setTitle(codePage.description, for: .normal)
                self?.currentCodePage = codePage
            }))
        }
        controller.addAction(.init(title: "Cancel", style: .cancel, handler: nil))
        present(controller, animated: true, completion: nil)
    }
    
    @IBAction func acceptSetting(_ sender:UIButton){

        let ics = (currentICS?.value ?? .USA).rawValue
        let codepage = Int((currentCodePage?.value ?? ._CP437).rawValue)

        let result = printer.setICS(ics, codepage: codepage)
        
        guard result == .SUCCESS else {
            presentTextAlert(msg: "Fail")
            return
        }
    }
    
    
}
